@@ -134,6 +134,7 @@ def get_config(name, config_file=None, allow_user=True, user_path=None,
 
     if user_path is not None:
         user_path = os.path.expanduser(os.path.expandvars(user_path))
+        assert os.path.exists(user_path), f'User path {user_path!r} not found.'
     else:
         # Test a few default paths and exit when finds one.
         extensions = ['.yaml', '.yml']
@@ -186,6 +187,8 @@ class Configuration(dict):
         else:
             self._BASE = {}
 
+        self.CONFIG_FILE = None
+
         __ENVVARS__ = default_envvars
 
         self.load(config)
@@ -219,5 +222,10 @@ class Configuration(dict):
 
         if config is None:
             config = {}
+            self.CONFIG_FILE = None
 
         super().__init__(self._parse_config(config))
+
+        # Save name of the configuration file (if the input is a file).
+        if isinstance(config, (str, pathlib.Path)):
+            self.CONFIG_FILE = str(config)
